@@ -2,7 +2,6 @@ from benedict.core import clone as _clone
 
 
 class BaseDict(dict):
-
     _dict = None
     _pointer = False
 
@@ -21,11 +20,11 @@ class BaseDict(dict):
         if len(args) == 1 and isinstance(args[0], dict):
             self._dict = self._get_dict_or_value(args[0])
             self._pointer = True
-            super(BaseDict, self).__init__(self._dict)
+            super().__init__(self._dict)
             return
         self._dict = None
         self._pointer = False
-        super(BaseDict, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def __bool__(self):
         if self._pointer:
@@ -35,7 +34,7 @@ class BaseDict(dict):
     def __contains__(self, key):
         if self._pointer:
             return key in self._dict
-        return super(BaseDict, self).__contains__(key)
+        return super().__contains__(key)
 
     def __deepcopy__(self, memo):
         obj = self.__class__()
@@ -47,32 +46,32 @@ class BaseDict(dict):
         if self._pointer:
             del self._dict[key]
             return
-        super(BaseDict, self).__delitem__(key)
+        super().__delitem__(key)
 
     def __eq__(self, other):
         if self._pointer:
             return self._dict == other
-        return super(BaseDict, self).__eq__(other)
+        return super().__eq__(other)
 
     def __getitem__(self, key):
         if self._pointer:
             return self._dict[key]
-        return super(BaseDict, self).__getitem__(key)
+        return super().__getitem__(key)
 
     def __iter__(self):
         if self._pointer:
             return iter(self._dict)
-        return super(BaseDict, self).__iter__()
+        return super().__iter__()
 
     def __len__(self):
         if self._pointer:
             return len(self._dict)
-        return super(BaseDict, self).__len__()
+        return super().__len__()
 
     def __repr__(self):
         if self._pointer:
             return repr(self._dict)
-        return super(BaseDict, self).__repr__()
+        return super().__repr__()
 
     def __setitem__(self, key, value):
         value = self._get_dict_or_value(value)
@@ -85,23 +84,27 @@ class BaseDict(dict):
                 return
             self._dict[key] = value
             return
-        super(BaseDict, self).__setitem__(key, value)
+        super().__setitem__(key, value)
+
+    def __setstate__(self, state):
+        self._dict = state["_dict"]
+        self._pointer = state["_pointer"]
 
     def __str__(self):
         if self._pointer:
             return str(self._dict)
-        return super(BaseDict, self).__str__()
+        return super().__str__()
 
     def clear(self):
         if self._pointer:
             self._dict.clear()
             return
-        super(BaseDict, self).clear()
+        super().clear()
 
     def copy(self):
         if self._pointer:
             return self._dict.copy()
-        return super(BaseDict, self).copy()
+        return super().copy()
 
     def dict(self):
         if self._pointer:
@@ -111,37 +114,37 @@ class BaseDict(dict):
     def get(self, key, default=None):
         if self._pointer:
             return self._dict.get(key, default)
-        return super(BaseDict, self).get(key, default)
+        return super().get(key, default)
 
     def items(self):
         if self._pointer:
             return self._dict.items()
-        return super(BaseDict, self).items()
+        return super().items()
 
     def keys(self):
         if self._pointer:
             return self._dict.keys()
-        return super(BaseDict, self).keys()
+        return super().keys()
 
     def pop(self, key, *args):
         if self._pointer:
             return self._dict.pop(key, *args)
-        return super(BaseDict, self).pop(key, *args)
+        return super().pop(key, *args)
 
     def setdefault(self, key, default=None):
         default = self._get_dict_or_value(default)
         if self._pointer:
             return self._dict.setdefault(key, default)
-        return super(BaseDict, self).setdefault(key, default)
+        return super().setdefault(key, default)
 
     def update(self, other):
         other = self._get_dict_or_value(other)
         if self._pointer:
             self._dict.update(other)
             return
-        super(BaseDict, self).update(other)
+        super().update(other)
 
     def values(self):
         if self._pointer:
             return self._dict.values()
-        return super(BaseDict, self).values()
+        return super().values()
