@@ -1,8 +1,16 @@
 import fsutil
-from openpyxl import load_workbook
-from slugify import slugify
-from xlrd import open_workbook
 
+try:
+    from openpyxl import load_workbook
+    from xlrd import open_workbook
+
+    xls_installed = True
+except ModuleNotFoundError:
+    xls_installed = False
+
+from slugify import slugify
+
+from benedict.extras import require_xls
 from benedict.serializers.abstract import AbstractSerializer
 
 
@@ -35,8 +43,10 @@ class XLSSerializer(AbstractSerializer):
         try:
             sheet_index = sheet_names.index(slugify(sheet_name))
             return sheet_index
-        except ValueError:
-            raise Exception(f"Invalid sheet name '{sheet_name}', sheet not found.")
+        except ValueError as error:
+            raise Exception(
+                f"Invalid sheet name {sheet_name!r}, sheet not found."
+            ) from error
 
     def _get_sheet_columns_indexes(self, columns_count):
         return [column_index for column_index in range(columns_count)]
@@ -136,6 +146,7 @@ class XLSSerializer(AbstractSerializer):
         return items
 
     def decode(self, s, **kwargs):
+        require_xls(installed=xls_installed)
         extension = fsutil.get_file_extension(s)
         if extension in ["xlsx", "xlsm"]:
             return self._decode(s, **kwargs)
@@ -143,4 +154,5 @@ class XLSSerializer(AbstractSerializer):
             return self._decode_legacy(s, **kwargs)
 
     def encode(self, d, **kwargs):
+        # require_xls(installed=xls_installed)
         raise NotImplementedError
